
# Slot: version




URI: [nwb_schema_language:version](https://w3id.org/p2p_ld/nwb-schema-language/version)


## Domain and Range

None &#8594;  <sub>1..1</sub> [String](types/String.md)

## Parents


## Children


## Used by

 * [Namespace](Namespace.md)
